"""
script for share fetching (by symbols (e.g. AAPL, TSLA etc.))
"""
__author__ = "Florian Kellermann, Linus Eickhoff"
__date__ = "15.03.2022"
__version__ = "1.0.0" 
__license__ = "None"

import investpy
import pandas

def get_share_price(str_search_for):
    """get stock price per share for company name or isin or symbol

    Args:
        str_search_for (string): search for this string/isin

    Returns: none
    """
    
    search_result = investpy.search_quotes(text=str_search_for, products=['stocks'], n_results=1, countries=['germany', 'united states'])

    currency = str(search_result.retrieve_currency())
    
    recent_data = pandas.DataFrame(search_result.retrieve_recent_data())
    
    stock_price = recent_data.iloc[-1]["Close"]
    
    str_return =str(stock_price) + " " + str(currency)
    
    return str_return


def get_share_price_no_currency(str_search_for):
    """get stock price per share for company name or isin or symbol no currency

    Args:
        str_search_for (string): search for this string/isin

    Returns: none
    """
    
    search_result = investpy.search_quotes(text=str_search_for, products=['stocks'],
                                            countries=['germany', 'united states'], n_results=1)
    
    recent_data = pandas.DataFrame(search_result.retrieve_recent_data())
    
    stock_price = recent_data.iloc[-1]["Close"]
    
    return stock_price


def get_share_information(str_search_for):
    search_result = investpy.search_quotes(text=str_search_for, products=['stocks'],
                                            countries=['germany', 'united states'], n_results=1)
    
    str_return = "Company: " + search_result.name + "\nSymbol: " + search_result.symbol + "\nCurrent Price/Share: " + get_share_price(str_search_for)
    
    return str_return
